Subpackages
===========

.. toctree::

   moduledoc/andes.core
   moduledoc/andes.io
   moduledoc/andes.models
   moduledoc/andes.routines
   moduledoc/andes.utils
   moduledoc/andes.variables

Submodules
==========

andes.cli module
----------------

.. automodule:: andes.cli
   :members:
   :undoc-members:
   :show-inheritance:

andes.main module
-----------------

.. automodule:: andes.main
   :members:
   :undoc-members:
   :show-inheritance:

andes.plot module
-----------------

.. automodule:: andes.plot
   :members:
   :undoc-members:
   :show-inheritance:

andes.shared module
-------------------

.. automodule:: andes.shared
   :members:
   :undoc-members:
   :show-inheritance:

andes.system module
-------------------

.. automodule:: andes.system
   :members:
   :undoc-members:
   :show-inheritance:
